@@ -32,7 +32,7 @@ nat1 const dbExprNode::commutativeOperator[] = {
 0};
 
 dbExprNode* dbExprNode::freeNodeList;
-dbMutex     dbExprNode::mutex;
+dbMutex&    dbExprNode::mutex = *new dbMutex;
 bool        dbCompiler::initialized;
 
 dbExprNodeSegment* dbExprNode::segmentList;
